@@ -38,6 +38,11 @@
 #define NAUTILUS_ACTION_SHOW_HIDE_STATUSBAR "Show Hide Statusbar"
 #define NAUTILUS_ACTION_SHOW_HIDE_LOCATION_BAR "Show Hide Location Bar"
 #define NAUTILUS_ACTION_GO_TO_BURN_CD "Go to Burn CD"
+#define NAUTILUS_ACTION_GO_TO_LOCATION "Go to Location"
+#define NAUTILUS_ACTION_GO_HOME "Home"
+#define NAUTILUS_ACTION_ADD_BOOKMARK "Add Bookmark"
+#define NAUTILUS_ACTION_EDIT_BOOKMARKS "Edit Bookmarks"
+#define NAUTILUS_ACTION_HOME "Home"
 #define NAUTILUS_ACTION_ZOOM_IN "Zoom In"
 #define NAUTILUS_ACTION_ZOOM_OUT "Zoom Out"
 #define NAUTILUS_ACTION_ZOOM_NORMAL "Zoom Normal"
