@@ -94,15 +94,27 @@ nautilus_connect_server_dialog_present_uri (NautilusApplication *application,
 int
 main (int argc, char *argv[])
 {
+	GnomeProgram *program;
 	GtkWidget *dialog;
+	GOptionContext *context;
+	const char **args;
+	const GOptionEntry options[] = {
+		{ G_OPTION_REMAINING, 0, 0, G_OPTION_ARG_STRING_ARRAY, &args, NULL,  N_("[URI]") },
+		{ NULL }
+	};
 
 	bindtextdomain (GETTEXT_PACKAGE, GNOMELOCALEDIR);
 	bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
 	textdomain (GETTEXT_PACKAGE);
 
-	gnome_program_init ("nautilus-connect-server", VERSION,
-			    LIBGNOMEUI_MODULE, argc, argv,
-			    NULL);
+	args = NULL;
+	context = g_option_context_new (_("\n\nAdd connect to server mount"));
+	g_option_context_add_main_entries (context, options, GETTEXT_PACKAGE);
+
+	program = gnome_program_init ("nautilus-connect-server", VERSION,
+				      LIBGNOMEUI_MODULE, argc, argv,
+				      GNOME_PARAM_GOPTION_CONTEXT, context,
+				      NULL);
 
 	gnome_authentication_manager_init ();
 
@@ -110,7 +122,9 @@ main (int argc, char *argv[])
 
 	gtk_window_set_default_icon_name ("gnome-fs-directory");
 
-	dialog = nautilus_connect_server_dialog_new (NULL, NULL);
+
+	/* command line arguments, null terminated array */
+	dialog = nautilus_connect_server_dialog_new (NULL, args != NULL ? *args : NULL);
 
 	open_dialogs = 1;
 	g_signal_connect (dialog, "destroy",
